==> haskell-apply-refact-0.8.2.1-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-apply-refact.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 apply-refact
version:              0.8.2.1
visibility:           public
id:                   apply-refact-0.8.2.1-Gtt2VpNMOgw3ycZ8ufH9LX
key:                  apply-refact-0.8.2.1-Gtt2VpNMOgw3ycZ8ufH9LX
license:              BSD-3-Clause
maintainer:           matthewtpickering@gmail.com
author:               Matthew Pickering
synopsis:             Perform refactorings specified by the refact library.
description:
    Perform refactorings specified by the refact library. It is primarily used with HLint'\''s --refactor flag.

category:             Development
abi:                  2d3eaa337d01bc8725cb3d6fa35689a9
exposed:              True
exposed-modules:      Refact.Apply Refact.Fixity Refact.Utils
hidden-modules:       Refact.Internal
import-dirs:          /usr/lib/ghc-8.10.3/site-local/apply-refact-0.8.2.1
library-dirs:         /usr/lib/ghc-8.10.3/site-local/apply-refact-0.8.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/apply-refact-0.8.2.1
hs-libraries:         HSapply-refact-0.8.2.1-Gtt2VpNMOgw3ycZ8ufH9LX
depends:
    base-4.14.1.0 containers-0.6.2.1 directory-1.3.6.0
    extra-1.7.9-AbslQZHhULfGhjSCwI9dbf
    filemanip-0.3.6.3-4Y8G3hE2pJJ8Zg9qpvRsH ghc-8.10.3
    ghc-exactprint-0.6.3.3-Fr4tGN4DvcD78DloUe9hLW process-1.6.9.0
    refact-0.3.0.2-6u7IO6ToowUCnxAhxxe42G
    syb-0.7.1-EJn6avnnYqseQTf54r0Yp transformers-0.5.6.2
    unix-compat-0.5.2-7IcOHcLTxJI58jp45CNrGP

haddock-interfaces:
    /usr/share/doc/haskell-apply-refact/html/apply-refact.haddock

haddock-html:         /usr/share/doc/haskell-apply-refact/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-apply-refact-0.8.2.1-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-apply-refact.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 apply-refact
version:              0.8.2.1
visibility:           public
id:                   apply-refact-0.8.2.1-4eXsIs5nLgKI7wmoWQheJp
key:                  apply-refact-0.8.2.1-4eXsIs5nLgKI7wmoWQheJp
license:              BSD-3-Clause
maintainer:           matthewtpickering@gmail.com
author:               Matthew Pickering
synopsis:             Perform refactorings specified by the refact library.
description:
    Perform refactorings specified by the refact library. It is primarily used with HLint'\''s --refactor flag.

category:             Development
abi:                  838a278bd9c80c7f0ae15e498e8b329f
exposed:              True
exposed-modules:      Refact.Apply Refact.Fixity Refact.Utils
hidden-modules:       Refact.Internal
import-dirs:          /usr/lib/ghc-8.10.3/site-local/apply-refact-0.8.2.1
library-dirs:         /usr/lib/ghc-8.10.3/site-local/apply-refact-0.8.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/apply-refact-0.8.2.1
hs-libraries:         HSapply-refact-0.8.2.1-4eXsIs5nLgKI7wmoWQheJp
depends:
    base-4.14.1.0 containers-0.6.2.1 directory-1.3.6.0
    extra-1.7.9-GRPDCTy1S0FLagan9oxSqB
    filemanip-0.3.6.3-4Y8G3hE2pJJ8Zg9qpvRsH ghc-8.10.3
    ghc-exactprint-0.6.3.3-IlKjmNwxGzh4p1Y2LJzQHC process-1.6.9.0
    refact-0.3.0.2-6u7IO6ToowUCnxAhxxe42G
    syb-0.7.1-EJn6avnnYqseQTf54r0Yp transformers-0.5.6.2
    unix-compat-0.5.2-7IcOHcLTxJI58jp45CNrGP

haddock-interfaces:
    /usr/share/doc/haskell-apply-refact/html/apply-refact.haddock

haddock-html:         /usr/share/doc/haskell-apply-refact/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
